"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Cooker = Cooker;
var _functionTree = _interopRequireWildcard(require("function-tree"));
var _createConfig = require("../helpers/createConfig");
var _parseArgs2 = require("../helpers/parseArgs");
var _runAll = require("../helpers/runAll");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function provide(path, config) {
  // Lazy loading of providers to avoid requiring
  // big libraries if they are not needed.
  var provider = require(path)["default"];
  return provider(config);
}
var PROVIDER = {
  git: './providers/GitProvider',
  github: './providers/GithubProvider',
  npm: './providers/NpmProvider',
  packageJson: './providers/PackageJsonProvider',
  vscode: './providers/VSCodeProvider'
};
var USE_ALL = Object.assign.apply(Object, [{}].concat(_toConsumableArray(Object.keys(PROVIDER).map(function (k) {
  return _defineProperty({}, k, true);
}))));
function Cooker(argv, theOptions) {
  if (arguments.length !== 2) {
    theOptions = argv;
    argv = [];
  }
  var _parseArgs = (0, _parseArgs2.parseArgs)(argv),
    cmd = _parseArgs.cmd,
    args = _parseArgs.args,
    builtin = _parseArgs.builtin;
  var options = Object.assign({}, theOptions);
  if (args.includes('--dry-run')) {
    options.dryRun = true;
  }
  if (args.includes('--devtools')) {
    options.useDevtools = true;
  }
  if (args.includes('--no-parallel')) {
    (0, _runAll.setParallelAllowed)(false);
  }
  var config = (0, _createConfig.createConfig)(options);
  var use = (builtin ? builtin.use : options.use) || USE_ALL;
  var customProviders = options.providers || {};
  var ft = new _functionTree["default"](Object.assign.apply(Object, [{
    config: config
  }].concat(_toConsumableArray(Object.keys(use).filter(function (k) {
    return use[k];
  }).map(function (k) {
    return _defineProperty({}, k, provide(PROVIDER[k], config));
  })), _toConsumableArray(Object.keys(customProviders).map(function (k) {
    return _defineProperty({}, k, customProviders[k](config));
  })))));
  if (options.useDevtools) {
    var Devtools = require('function-tree/devtools')["default"];
    var tools = new Devtools({
      host: options.devtools ? options.devtools.host : 'localhost:9090'
    });
    tools.add(ft);
  }
  var originalRun = ft.run;
  ft.run = function () {
    var hasProps = false;
    var args = [];
    var defaultProps = {
      config: config,
      argv: argv,
      cmd: cmd
    };
    for (var _len = arguments.length, theArgs = new Array(_len), _key = 0; _key < _len; _key++) {
      theArgs[_key] = arguments[_key];
    }
    theArgs.forEach(function (arg, idx) {
      if (Array.isArray(arg) || arg instanceof _functionTree.Primitive) {
        args[idx] = arg;
      } else if (_typeof(arg) === 'object') {
        hasProps = true;
        args[idx] = Object.assign({}, defaultProps, arg);
      } else {
        args[idx] = arg;
      }
    });
    if (!hasProps) {
      args.push(defaultProps);
    }
    return originalRun.apply(ft, args);
  };
  ft.cook = function (name) {
    for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
      args[_key2 - 1] = arguments[_key2];
    }
    return ft.run.apply(ft, [name].concat(args))["catch"](function (err) {
      console.log('');
      console.log(err.payload.error.stack);
      if (options.useDevtools) {
        // Keep it running
      } else {
        var displayName = typeof name === 'string' ? "".concat(name, ": ") : '';
        console.log("\n\x1B[31m** ".concat(displayName, "execution FAILED **\x1B[0m"));
        setTimeout(function () {
          process.exit(-1);
        }, 0);
      }
    });
  };
  if (builtin) {
    ft.cook("run ".concat(builtin.name), builtin.sequence);
  }
  return ft;
}
//# sourceMappingURL=index.js.map