"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GitProvider = GitProvider;
exports["default"] = void 0;
var _functionTree = require("function-tree");
var _getBranches2 = require("./getBranches");
var _getCommit2 = require("./getCommit");
var _getCurrentBranch2 = require("./getCurrentBranch");
var _getHashListFromHash2 = require("./getHashListFromHash");
var _getLatestTagMatchingName2 = require("./getLatestTagMatchingName");
var _restoreRepository2 = require("./restoreRepository");
function GitProvider(_ref) {
  var path = _ref.path,
    runCommand = _ref.runCommand;
  return new _functionTree.Provider({
    createTagForCommit: function createTagForCommit(tag) {
      var message = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      return runCommand('git', ['tag', '-a', tag, '-m', JSON.stringify(message)]);
    },
    getBranches: function getBranches() {
      return (0, _getBranches2.getBranches)(path);
    },
    getCommit: function getCommit(hash) {
      return (0, _getCommit2.getCommit)(path, hash);
    },
    getCurrentBranch: function getCurrentBranch() {
      return (0, _getCurrentBranch2.getCurrentBranch)(path);
    },
    getHashListFromHash: function getHashListFromHash(hash) {
      return (0, _getHashListFromHash2.getHashListFromHash)(path, hash);
    },
    getLatestTagMatchingName: function getLatestTagMatchingName(tag) {
      return (0, _getLatestTagMatchingName2.getLatestTagMatchingName)(path, tag);
    },
    pushTagToRemote: function pushTagToRemote(tagName) {
      var remoteName = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'origin';
      return runCommand('git', ['push', remoteName, tagName]);
    },
    restoreRepository: function restoreRepository() {
      // Has side effects so we wrap with runCommand
      return runCommand(_restoreRepository2.restoreRepository, [path]);
    }
  });
}
var _default = exports["default"] = GitProvider;
//# sourceMappingURL=index.js.map