"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createRelease = createRelease;
var _axios = _interopRequireDefault(require("axios"));
var _path = require("../../../helpers/path");
var _fs = require("fs");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { "default": e }; }
var REPO_URL_RE = /^.*:\/\/([^/]+)\/([^/]+)\/([^.]+)/;
function getRepositoryInfo(path) {
  return new Promise(function (resolve, reject) {
    var packageJsonPath = (0, _path.join)(path, 'package.json');
    (0, _fs.readFile)(packageJsonPath, function (err, data) {
      if (err) {
        reject(new Error("Could not read '".concat(packageJsonPath, "' (").concat(err, ").")));
      }
      resolve(JSON.parse(data));
    });
  }).then(function (details) {
    var repository = details.repository;
    if (!repository) {
      throw new Error("Cannot find repository url: missing 'repository' entry in package.json.");
    }
    var url = repository.url;
    if (!url) {
      throw new Error("Cannot find repository url: missing 'url' entry in 'repository' in package.json.");
    }
    var match = REPO_URL_RE.exec(url);
    if (!match) {
      throw new Error("Could not parse repository url '".concat(url, "'."));
    }
    return {
      domain: match[1],
      owner: match[2],
      repo: match[3]
    };
  });
}
function createRelease(path, tagName, body) {
  // POST /repos/:owner/:repo/releases
  var data = {
    tag_name: tagName,
    name: tagName,
    body: body,
    draft: false,
    prerelease: false
  };
  var headers = {
    'User-Agent': 'repo-cooker',
    Accept: 'application/vnd.github+json',
    Authorization: "Bearer ".concat(process.env.REPO_COOKER_GITHUB_TOKEN || process.env.GH_TOKEN),
    'X-GitHub-Api-Version': '2022-11-28'
  };
  return new Promise(function (resolve, reject) {
    getRepositoryInfo(path).then(function (_ref) {
      var domain = _ref.domain,
        owner = _ref.owner,
        repo = _ref.repo;
      if (domain !== 'github.com') {
        reject(new Error("Release to domain '".concat(domain, "' is not supported (please use 'github.com').")));
      }
      var url = "https://api.".concat(domain, "/repos/").concat(owner, "/").concat(repo, "/releases");
      return _axios["default"].post(url, data, {
        headers: headers
      }).then(function (response) {
        resolve(response.data);
      })["catch"](function (error) {
        if (error.response) {
          var errorInfo = '';
          for (var entry in error.response.data) {
            errorInfo += "\n  ".concat(entry, ": '").concat(error.response.data[entry], "'");
          }
          reject(new Error('Request failed with status code ' + error.response.status + errorInfo));
        } else {
          reject(new Error(error));
        }
      });
    })["catch"](reject);
  });
}
//# sourceMappingURL=createRelease.js.map