"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkDependencies = checkDependencies;
var _path = require("../helpers/path");
var _fs = require("fs");
var dependencyTypes = ['dependencies', 'devDependencies'];

/*
  Given a `dependencies` object in props, produce a summary of conflicts
  and updates for monorepo dependencies.
*/
function checkDependencies(_ref) {
  var config = _ref.config,
    props = _ref.props;
  var monorepo = JSON.parse((0, _fs.readFileSync)((0, _path.join)(config.path, 'package.json'), 'utf8'));
  var packageDeps = props.dependencies;
  if (!packageDeps) {
    throw new Error("No 'dependencies' in props. Missing 'getDependencies' action ?");
  }
  /**
   * type: 'install' | 'conflict' | 'noop'
   * dependency: dependency
   * monoVersion: => version in monorepo
   * version: version to install
   * packages: => key: version-in-package
   */

  var result = {};
  dependencyTypes.forEach(function (dependencyType) {
    var operations = {};
    Object.keys(packageDeps).forEach(function (packageName) {
      var dependencies = packageDeps[packageName][dependencyType];
      var monodeps = monorepo[dependencyType];
      if (dependencies) {
        Object.keys(dependencies).forEach(function (dependency) {
          // For each dependency in a specif package.
          if (packageDeps[dependency]) {
            // Dependency to our own libs: ignore
            return;
          }
          var packageExactVersion = dependencies[dependency];
          var packageVersion = packageExactVersion.replace('^', '');
          var monoVersion = monodeps[dependency];
          var update = operations[dependency];
          if (!update) {
            // Simply store the first time we see this dependency.
            update = operations[dependency] = {
              dependency: dependency,
              monoVersion: monoVersion,
              packages: {},
              type: 'noop'
            };
          }
          // Add the version used in this package to the `packages` field.
          update.packages[packageName] = packageExactVersion;
          if (!update.version) {
            // No change yet.
            if (packageVersion !== update.monoVersion) {
              // Need to update to monorepo version.
              update.type = 'install';
              update.version = packageVersion;
            }
          } else if (update.version === packageVersion) {
            // OK: same version in other package.
          } else {
            // Conflicting versions in packages.
            update.type = 'conflict';
          }
        });
      }
    });

    // Create summary.
    var toInstall = Object.keys(operations).filter(function (k) {
      return operations[k].type === 'install';
    }).map(function (k) {
      return operations[k];
    });

    // Conflicting versions.
    var conflict = Object.keys(operations).filter(function (k) {
      return operations[k].type === 'conflict';
    }).map(function (k) {
      return operations[k];
    });
    result[dependencyType] = {
      toInstall: toInstall,
      conflict: conflict
    };
  });
  return {
    checkDependencies: result
  };
}
//# sourceMappingURL=checkDependencies.js.map