"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.evaluateNewVersionByPackage = evaluateNewVersionByPackage;
var _helpers = require("./helpers");
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
var TYPES = ['major', 'minor', 'patch'];
var RTYPES = ['patch', 'minor', 'major'];
var VERSION_RE = /^(\d+)\.(\d+)\.(\d+)/;
function evaluateVersion(version, type, packageName, semver) {
  if (!type) {
    if (semver) {
      // Semver was provided but is wrong.
      throw new Error("Invalid semver type '".concat(semver, "' for package '").concat(packageName, "'."));
    }
    // No changes
    return version;
  }
  var re = VERSION_RE.exec(version);
  if (!re) {
    throw new Error("Invalid version '".concat(version, "' for package '").concat(packageName, "' (format should be '[integer].[integer].[integer][anything]')."));
  }
  var parts = [re[1], re[2], re[3]].map(function (l) {
    return parseInt(l);
  });
  var idx = TYPES.indexOf(type);
  return [].concat(parts.slice(0, idx), [[parts[idx] + 1]], parts.slice(idx + 1).map(function (n) {
    return 0;
  })).join('.');
}
function evaluateNewVersionByPackage(_ref) {
  var _ref$props = _ref.props,
    currentVersionByPackage = _ref$props.currentVersionByPackage,
    semverByPackage = _ref$props.semverByPackage,
    relatedPackagesByPackage = _ref$props.relatedPackagesByPackage;
  function resolve(packageName) {
    // Bump version according to package dependencies
    return Math.max.apply(Math, _toConsumableArray(Object.keys((0, _helpers.forwardGraph)(relatedPackagesByPackage, [packageName])).map(function (packageName) {
      return packageName in semverByPackage ? RTYPES.indexOf(semverByPackage[packageName]) : -1;
    })));
  }
  var newVersionByPackage = Object.keys(
  // We evaluate for all packages related to changed packages
  currentVersionByPackage).sort().reduce(function (newVersionByPackage, packageName) {
    newVersionByPackage[packageName] = currentVersionByPackage[packageName] === null ? '1.0.0' : evaluateVersion(currentVersionByPackage[packageName], RTYPES[resolve(packageName)], packageName, semverByPackage[packageName]);
    return newVersionByPackage;
  }, {});
  return {
    newVersionByPackage: newVersionByPackage
  };
}
//# sourceMappingURL=evaluateNewVersionByPackage.js.map