"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.evaluateSemverByPackage = evaluateSemverByPackage;
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
var SEMVER_TYPES = ['noop', 'patch', 'minor', 'major'];
var TYPE_TO_SEMVER = {
  feat: 'minor',
  fix: 'patch'
};
function getType(commits) {
  var types = commits.map(function (commit) {
    return commit.breaks.length ? 'major' : TYPE_TO_SEMVER[commit.type];
  }).map(function (type) {
    return SEMVER_TYPES.indexOf(type);
  });
  var type = Math.max.apply(Math, _toConsumableArray(types).concat([0]));
  return SEMVER_TYPES[type];
}
function evaluateSemverByPackage(_ref) {
  var props = _ref.props;
  var isBigBang = props.hash === 'Big Bang';
  var commitsByPackage = props.commitsByPackage;
  var packages = Object.keys(commitsByPackage);
  var semverByPackage = packages.map(function (name) {
    return getType(commitsByPackage[name]);
  }).reduce(function (semverByPackage, type, index) {
    if (isBigBang) {
      semverByPackage[packages[index]] = 'major';
    } else if (type !== 'noop') {
      semverByPackage[packages[index]] = type;
    }
    return semverByPackage;
  }, {});
  return {
    semverByPackage: semverByPackage
  };
}
//# sourceMappingURL=evaluateSemverByPackage.js.map