"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCurrentVersionByPackage = getCurrentVersionByPackage;
var _helpers = require("./helpers");
var _runAll = require("../helpers/runAll");
function getCurrentVersionByPackage(ctx) {
  var props = ctx.props,
    packageJson = ctx.packageJson;
  var semverByPackage = props.semverByPackage,
    relatedPackagesByPackage = props.relatedPackagesByPackage;
  var changedPackages = Object.keys(semverByPackage);
  var touchedPackages = Object.keys(Object.assign((0, _helpers.forwardGraph)(relatedPackagesByPackage, changedPackages), (0, _helpers.backwardGraph)(relatedPackagesByPackage, changedPackages)));
  return (0, _runAll.runAll)(touchedPackages.map(function (name) {
    return packageJson.get(name).then(function (info) {
      var type = info.publishTo || 'npm';
      var getter = ctx[type];
      if (!getter) {
        throw new Error("Unknown publishType '".concat(type, "' for package '").concat(name, "'."));
      }
      return getter.getCurrentPackageVersion(name, info).then(function (version) {
        return {
          name: name,
          version: version
        };
      });
    });
  }))
  // Sort packages by name for consistent output
  .then(function (results) {
    return results.sort(function (a, b) {
      return a.name < b.name ? -1 : 1;
    });
  }).then(function (results) {
    return {
      currentVersionByPackage: results.reduce(function (acc, r) {
        acc[r.name] = r.version;
        return acc;
      }, {})
    };
  });
}
//# sourceMappingURL=getCurrentVersionByPackage.js.map