"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.groupCommitsByPackage = groupCommitsByPackage;
var _path = require("../helpers/path");
/*
  By looking at files changed we can match the name of
  the package
*/
function matchPackage(filePath, config) {
  var fullpath = (0, _path.resolve)(config.path, filePath);
  for (var packageName in config.packagesPaths) {
    if (fullpath.indexOf(config.packagesPaths[packageName] + '/') === 0) {
      return packageName;
    }
  }

  // Not in any package
  return 'monorepo';
}

/*
  Returns:
  {
    commitsByPackage: {
      packageA: [{commitA}, {commitB}],
      packageB: [{commitA}, {commitC}]
    }
  }
*/
function groupCommitsByPackage(_ref) {
  var config = _ref.config,
    props = _ref.props;
  var commits = [];
  var commitsWithoutPackage = [];
  return {
    // we add 'packagesAffected' in commits
    commits: commits,
    /*
      By looking at file paths change we can identify what packages
      are affected by this change
    */
    commitsByPackage: props.commits.reduce(function (commitsByPackage, commit) {
      /*
        Extract packages affected by matching file path changed with
        defined packages in config
      */
      var affectedPackages = commit.files.reduce(function (packagesAffected, file) {
        var packageName = matchPackage(file, config);
        if (packageName && packagesAffected.indexOf(packageName) === -1) {
          return packagesAffected.concat(packageName);
        }
        return packagesAffected;
      }, [])
      /*
        Exclude monorepo when commit affects other packages
      */.filter(function (packageName, _, array) {
        if (packageName === 'monorepo' && array.length > 1) {
          return false;
        }
        return true;
      });
      commits.push(Object.assign({}, commit, {
        affectedPackages: affectedPackages
      }));
      /*
        Put commit into each package array
      */
      affectedPackages.forEach(function (packageName) {
        if (!commitsByPackage[packageName]) {
          commitsByPackage[packageName] = [];
        }
        commitsByPackage[packageName].push(commit);
      });

      /*
        Move commits not related to any package to commitsWithoutPackage
      */
      if (commitsByPackage.monorepo) {
        commitsByPackage.monorepo.forEach(function (commitWithoutPackage) {
          commitsWithoutPackage.push(commitWithoutPackage);
        });
      }
      delete commitsByPackage.monorepo;
      return commitsByPackage;
    }, {}),
    commitsWithoutPackage: commitsWithoutPackage
  };
}
//# sourceMappingURL=groupCommitsByPackage.js.map