"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.publishByType = publishByType;
var _execCommand = require("../helpers/execCommand");
var _runAll = require("../helpers/runAll");
function publishByType(ctx) {
  var config = ctx.config,
    packageJson = ctx.packageJson,
    props = ctx.props;
  var packages = Object.keys(props.newVersionByPackage).filter(function (name) {
    return props.newVersionByPackage[name] !== props.currentVersionByPackage[name];
  });

  // Need to ensure successful release of all packages, so
  // we publish under a temporary tag first
  return (0, _runAll.runAll)(packages.map(function (name) {
    return packageJson.get(name).then(function (info) {
      if (info["private"]) {
        return null;
      } else {
        var type = info.publishTo || 'npm';
        if (!ctx[type]) {
          throw new Error("Missing provider for publishType '".concat(type, "' for package '").concat(name, "'."));
        } else if (ctx[type].validateVersion) {
          var newVersion = props.newVersionByPackage[name];
          if (!ctx[type].validateVersion(newVersion)) {
            (0, _execCommand.logCommand)('skip publish', [type, name], {
              version: newVersion
            });
            return null;
          }
        }
        return {
          name: name,
          type: type
        };
      }
    });
  })).then(function (results) {
    return results.filter(function (result) {
      return result !== null;
    });
  }).then(function (results) {
    return (0, _runAll.runAll)(results.map(function (_ref) {
      var name = _ref.name,
        type = _ref.type;
      return ctx[type].publish(name, 'releasing');
    })).then(function () {
      return {
        temporaryNpmTagByPackage: results.reduce(function (temporaryNpmTagByPackage, _ref2) {
          var name = _ref2.name,
            type = _ref2.type;
          if (type === 'npm') {
            temporaryNpmTagByPackage[name] = 'releasing';
          }
          return temporaryNpmTagByPackage;
        }, {})
      };
    }).then(function (arg) {
      return config.dryRun ? arg : new Promise(function (resolve) {
        return setTimeout(function () {
          return resolve(arg);
        }, 3000);
      });
    });
  });
}
//# sourceMappingURL=publishByType.js.map