"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.avatarNotes = avatarNotes;
var _md = _interopRequireDefault(require("md5"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { "default": e }; }
var DEFAULT_TYPE_HEADERS = {
  feat: ':fire: Feature change',
  fix: ':bug: Bug fixes',
  docs: ':paperclip: Documentation',
  chore: ':wrench: Chores',
  style: ':pencil2: Styling',
  refactor: ':mag: Refactors',
  perf: ':runner: Performance',
  test: ':vertical_traffic_light: Tests',
  ts: ':pencil: Typescript'
};
function createNewVersionsTable(release) {
  var entries = Object.keys(release.newVersionByPackage).filter(function (packageName) {
    return release.newVersionByPackage[packageName] && release.newVersionByPackage[packageName] !== release.currentVersionByPackage[packageName];
  }).map(function (packageName) {
    return "| ".concat(packageName, " | ").concat(release.currentVersionByPackage[packageName] || '', " | ").concat(release.newVersionByPackage[packageName], " |");
  });
  if (!entries.length) {
    return '';
  }
  return "## Updated packages\n\n| package | from version | to version |\n|:---|:---|:---|\n".concat(entries.join('\n'), "\n");
}
function affected(commit, pkgCount) {
  if (commit.affectedPackages.length === pkgCount) {
    return 'all';
  } else {
    return commit.affectedPackages.join(', ');
  }
}
function createChangeTable(header, pkgCount, commits) {
  if (!commits || commits.length === 0) {
    return '';
  }
  return "## ".concat(header, "\n| package | summary | commit | issues | author | gravatar |\n|:---|:---|:---|:---|:---|---|\n").concat(commits.map(function (commit) {
    return "| ".concat(affected(commit, pkgCount), " | ").concat(commit.summary, " | ").concat(commit.hash, " | ").concat(commit.issues.join(', '), " | ").concat(commit.author.name, " | ![").concat(commit.author.name, "](https://www.gravatar.com/avatar/").concat((0, _md["default"])(commit.author.email), "?s=40) |");
  }).join('\n'), "\n");
}
function createBreakingTable(release) {
  var breaking = release.commits.filter(function (commit) {
    return commit.breaks.length > 0;
  });
  var pkgCount = Object.keys(release.currentVersionByPackage).length;
  if (breaking.length === 0) {
    return '';
  }
  return "## :rotating_light: Breaking\n| package | summary | commit | issues | author | gravatar |\n|:---|:---|:---|:---|:---|---|\n".concat(breaking.map(function (commit) {
    return "| ".concat(affected(commit, pkgCount), " | ").concat(commit.summary, " <ul>").concat(commit.breaks.map(function (text) {
      return "<li>*".concat(text, "*</li>");
    }).join(''), "</ul> | ").concat(commit.hash, " | ").concat(commit.issues.join(', '), " | ").concat(commit.author.name, " | ![").concat(commit.author.name, "](https://www.gravatar.com/avatar/").concat((0, _md["default"])(commit.author.email), "?s=40) |");
  }).join('\n'), "\n");
}
function createChangesTables(release, typeHeaders) {
  var pkgCount = Object.keys(release.currentVersionByPackage).length;
  return Object.keys(typeHeaders).map(function (type) {
    return createChangeTable(typeHeaders[type], pkgCount, release.commitsByType[type]);
  }).join('\n');
}
function avatarNotes(release, options) {
  var typeHeaders = options.typeHeaders || DEFAULT_TYPE_HEADERS;
  return "\n".concat(createNewVersionsTable(release), "\n").concat(createBreakingTable(release), "\n").concat(createChangesTables(release, typeHeaders), "\n");
}
//# sourceMappingURL=avatar.js.map