#!/usr/bin/env node
"use strict";

var _path = require("./helpers/path");
var _fs = require("fs");
var _parseArgs2 = require("./helpers/parseArgs");
var _crossSpawn = require("cross-spawn");
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; } // repo-cooker [cmd] [props] --dry-run --devtools
// 1. Looks for [cmd] in
//    './[repo-cooker path]/cmd.js'
//    './[repo-cooker path]/cmd/index.js'
//    The `[repo-cooker path]` can be defined in package.json
//    with 'repo-cooker-path' or is set to the default './repo-cooker'
// 2. If [cmd] is not found, uses the builtin
//    `run` command to run the given [cmd] in all packages
//    that contain the given script.
var rootPath = '.';
function fileExist(path) {
  try {
    var stats = (0, _fs.statSync)(path);
    return stats.isFile();
  } catch (err) {
    return false;
  }
}
var packagePath = (0, _path.join)(rootPath, 'package.json');
var packageInfo = JSON.parse((0, _fs.readFileSync)(packagePath, {
  encoding: 'utf8'
}));
var receiptsPath = packageInfo['repo-cooker-path'] || 'repo-cooker';
var _parseArgs = (0, _parseArgs2.parseArgs)(process.argv),
  cmd = _parseArgs.cmd,
  args = _parseArgs.args,
  builtin = _parseArgs.builtin;
var cmdPath;
if (cmd) {
  cmdPath = [(0, _path.join)(receiptsPath, "".concat(cmd, ".js")), (0, _path.join)(receiptsPath, "".concat(cmd, "/index.js"))].find(fileExist);
}
var fullCmdPath;
if (cmdPath) {
  // Found a custom script for this command.
  fullCmdPath = (0, _path.resolve)(cmdPath);
  console.log("Running script: ".concat(fullCmdPath));
} else {
  // Run a native signal. Just load the configuration.
  fullCmdPath = (receiptsPath.slice(-3) === '.js' ? [(0, _path.resolve)(receiptsPath)] : [(0, _path.resolve)("".concat(receiptsPath, ".js")), (0, _path.resolve)((0, _path.join)(receiptsPath, 'index.js'))]).find(fileExist);
  if (!fullCmdPath) {
    throw new Error("Missing repo-cooker setup file at '".concat(receiptsPath, "'."));
  }
  if (cmd) {
    args.unshift(cmd);
  }
  if (!builtin) {
    args.unshift('--builtin=run');
  }
}
console.log("> babel-node --presets @babel/preset-env ".concat(fullCmdPath, " ").concat(args.join(' ')));
var child = (0, _crossSpawn.spawn)('babel-node', ['--presets', '@babel/preset-env', fullCmdPath].concat(_toConsumableArray(args)), {
  stdio: 'inherit'
});
child.on('close', function (code) {
  process.exit(code);
});
//# sourceMappingURL=cli.js.map