"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.execCommand = execCommand;
exports.logCommand = logCommand;
exports.readableCommand = readableCommand;
var _crossSpawn = require("cross-spawn");
var _fs = require("fs");
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
var PAUSE_MS = 8000;
function findName(cmd) {
  if (typeof cmd === 'string') {
    return cmd;
  } else if (cmd.name) {
    return cmd.name;
  } else if (cmd === _fs.writeFile) {
    return 'fs.writeFile';
  } else {
    return 'native';
  }
}
function isStringified(string) {
  return Boolean(typeof string === 'string' && string.match(/(\{|\[)[\s\S]*(\}|\])$/));
}
function readableCommand(cmd, args, options) {
  return {
    cmd: findName(cmd),
    args: args.map(function (arg) {
      return typeof arg === 'function' ? '()' : arg;
    }).map(function (arg) {
      return isStringified(arg) ? '[data]' : arg;
    }),
    options: options
  };
}
function limit(text) {
  var str = text.split('\n').join('\\n');
  return str.length > 50 ? '...' + str.slice(-47) : str;
}
function logCommand(cmd, args, options) {
  var command = readableCommand(cmd, args, options);
  console.log("\n\x1B[33m".concat(command.cmd, "\x1B[0m\n    ").concat(command.args.map(function (arg) {
    return typeof arg === 'string' ? limit(arg) : JSON.stringify(arg);
  }).join('\n    ')).concat(options ? '\n    ' + JSON.stringify(options) : ''));
  return Promise.resolve([]);
}
var FAIL = '\x1b[31m    FAIL\x1b[0m';
var PASS = '\x1b[32m    OK\x1b[0m';
function execCommand(cmd) {
  var args = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var options = arguments.length > 2 ? arguments[2] : undefined;
  if (typeof cmd === 'function') {
    if (options) {
      throw new Error("'options' parameter not supported when running a function.");
    } else if (!Array.isArray(args)) {
      throw new Error("Please provide function arguments as an Array.");
    }
    return new Promise(function (resolve, reject) {
      cmd.apply(void 0, _toConsumableArray(args)).then(function (x) {
        logCommand(cmd, args, options);
        console.log(PASS);
        resolve(x);
      })["catch"](function (err) {
        logCommand(cmd, args, options);
        console.log(FAIL);
        reject(err);
      });
    });
  }
  var opts = Object.assign({}, options || {});
  var pause = opts.pause;
  delete opts.pause;
  return new Promise(function (resolve, reject) {
    var child = (0, _crossSpawn.spawn)(cmd, args, opts);
    var out = [];
    child.stdout.setEncoding('utf-8');
    child.stderr.setEncoding('utf-8');
    child.stdout.on('data', function (data) {
      out.push(data);
    });
    child.stderr.on('data', function (data) {
      out.push(data);
    });
    child.on('close', function (code) {
      if (code === 0) {
        logCommand(cmd, args, options);
        console.log(PASS);
        console.log(out.join('\n'));
        if (pause) {
          setTimeout(function () {
            resolve(out.join('\n'));
          }, PAUSE_MS);
        } else {
          resolve(out.join('\n'));
        }
      } else {
        logCommand(cmd, args, options);
        console.log(FAIL);
        console.log(out.join('\n'));
        reject(out.join('\n'));
      }
    });
  });
}
//# sourceMappingURL=execCommand.js.map