"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseCommit = parseCommit;
var _parseHeader = require("./parseHeader");
var breakingRe = /^\s*BREAKING CHANGES?:/;
var issuesRe = /^\s*ISSUES CLOSED:\s*(.*)$/;

/**
 * type(scope): message
 *
 * Yada yada yada
 *
 * yada yada yada
 *
 * ISSUES CLOSED: #xxx, #yyy
 * BREAKING CHANGE:
 * - this
 * - that
 */
function parseCommit(commit) {
  var message = commit.message;
  var lines = message.split('\n');
  var header = lines.shift();
  var body = [];
  var issues = [];
  var breaks = [];
  var current = body;
  lines.forEach(function (line) {
    if (breakingRe.test(line)) {
      current = breaks;
    } else if (issuesRe.test(line)) {
      issues = issuesRe.exec(line)[1].split(',').map(function (s) {
        return s.trim();
      });
      current = body;
    } else {
      current.push(line.trim());
    }
  });
  return Object.assign({}, commit, {
    body: body.join('\n').trim(),
    issues: issues,
    breaks: breaks.filter(function (b) {
      return b !== '';
    })
  }, (0, _parseHeader.parseHeader)(header));
}
//# sourceMappingURL=parseCommit.js.map